@@ -34,22 +34,24 @@ exponentiate <- function(data, col = "estimate") {
 #' @return A `tibble` potentially with a `.rownames` column
 #' @noRd
 #'
-
-
-as_augment_tibble <- function(data) {
+as_augment_tibble <- function(data, arg = caller_arg(data), call = caller_env()) {
   if (inherits(data, "matrix") & is.null(colnames(data))) {
-    stop(
-      "The supplied `data`/`newdata` argument was an unnamed matrix. ",
-      "Please supply a matrix or dataframe with column names."
-    )
+    cli::cli_abort(c(
+      "{.arg {arg}} is an unnamed matrix.",
+      "i" = "Please supply a matrix or data frame with column names."
+    ))
   }
 
   tryCatch(
     df <- as_tibble(data),
     error = function(cnd) {
-      stop("Could not coerce data to `tibble`. Try explicitly passing a",
-        "dataset to either the `data` or `newdata` argument.",
-        call. = FALSE
+      cli::cli_abort(
+        c(
+          "Could not coerce {.arg {arg}} to a tibble.",
+          "i" = "Try explicitly passing a data frame to either the {.arg data} or
+                 {.arg newdata} argument."
+        ),
+        call = call
       )
     }
   )
@@ -67,7 +69,7 @@ as_augment_tibble <- function(data) {
 is_cran_check <- function() {
   if (identical(Sys.getenv("NOT_CRAN"), "true")) {
     FALSE
-  }
+  } 
   else {
     Sys.getenv("_R_CHECK_PACKAGE_NAME_", "") != ""
   }
@@ -86,7 +88,10 @@ is_cran_check <- function() {
 #' @noRd
 as_tidy_tibble <- function(x, new_names = NULL, new_column = "term") {
   if (!is.null(new_names) && length(new_names) != ncol(x)) {
-    stop("newnames must be NULL or have length equal to number of columns")
+    cli::cli_abort(
+      "{.arg new names} must be {.code NULL} or have length equal to
+       number of columns ({ncol(data)})."
+    )
   }
 
   ret <- x
@@ -164,9 +169,9 @@ as_glance_tibble <- function(..., na_types) {
   cols <- list(...)
 
   if (length(cols) != stringr::str_length(na_types)) {
-    stop(
-      "The number of columns provided does not match the number of ",
-      "column types provided."
+    cli::cli_abort(
+      "The number of columns provided does not match the number of 
+       column {.emph types} provided."
     )
   }
 
@@ -305,10 +310,12 @@ augment_columns <- function(x, data, newdata = NULL, type, type.predict = type,
     if (inherits(na_action, "exclude")) {
       # check if values are missing
       if (length(stats::residuals(x)) > nrow(data)) {
-        warning(
-          "When fitting with na.exclude, rows with NA in ",
-          "original data will be dropped unless those rows are provided ",
-          "in 'data' argument"
+        cli::cli_warn(
+          c(
+            "When fitting with {.code na.exclude}, rows with {.code NA}s in
+             original data will be dropped unless those rows are provided
+             in the {.arg data} argument."
+          )
         )
       }
     }
@@ -362,10 +369,10 @@ response <- function(object, newdata = NULL, has_response) {
   res
 }
 
-data_error <- function(cnd) {
-  stop(
-    "Must specify either `data` or `newdata` argument.",
-    call. = FALSE
+data_error <- function(cnd, call = caller_env()) {
+  cli::cli_abort(
+    "Must specify either {.arg data} or {.arg newdata} argument.",
+    call = call
   )
 }
 
