@@ -1,12 +1,10 @@
-context("drc")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("drc")
-library(drc)
+suppressPackageStartupMessages(library(drc))
 
 mod <- drm(dead / total ~ conc, type,
   weights = total, data = selenium, fct = LL.2(), type = "binomial"
@@ -42,11 +40,8 @@ test_that("glance.drc", {
 })
 
 test_that("augment.drc", {
-  expect_error(
-    augment(mod),
-    regexp = "Must specify either `data` or `newdata` argument."
-  )
-
+  expect_snapshot(error = TRUE, augment(mod))
+  
   check_augment_function(
     augment.drc,
     mod,
@@ -54,11 +49,8 @@ test_that("augment.drc", {
     newdata = selenium
   )
 
-  expect_error(
-    augment(mod2),
-    regexp = "Must specify either `data` or `newdata` argument."
-  )
-
+  expect_snapshot(error = TRUE, augment(mod2))
+  
   check_augment_function(
     augment.drc,
     mod2,
