@@ -1,12 +1,10 @@
-context("glmnetUtils")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("glmnetUtils")
-library(glmnetUtils)
+suppressPackageStartupMessages(library(glmnetUtils))
 
 set.seed(27)
 
@@ -14,6 +12,8 @@ skip_if_not_installed("modeldata")
 library(modeldata)
 data(hpc_data)
 
+hpc_data <- hpc_data[1:300, ]
+
 fit <- glmnet(formula = mpg ~ ., data = mtcars)
 fit2 <- glmnet(
   formula = class ~ compounds + input_fields + iterations + num_pending,
@@ -56,10 +56,10 @@ test_that("tidy.glmnet.formula", {
   check_tidy_output(td2)
   check_tidy_output(td2z)
 
-  expect_is(td2, "tbl_df")
+  expect_s3_class(td2, "tbl_df")
 
-  expect_equal(dim(td2), c(983L, 6L))
-  expect_equal(dim(td2z), c(1240L, 6L))
+  expect_equal(dim(td2), c(1511L, 6L))
+  expect_equal(dim(td2z), c(2000L, 6L))
 
   expect_true(all(td2$estimate != 0))
   expect_true(any(td2z$estimate == 0))
@@ -75,6 +75,6 @@ test_that("glance.glmnet.formula", {
 
   check_glance_outputs(gl, gl2)
 
-  expect_is(gl, "tbl_df")
+  expect_s3_class(gl, "tbl_df")
   expect_equal(dim(gl), c(1L, 3L))
 })
