@@ -1,15 +1,13 @@
-context("lmtest")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("lmtest")
-library(lmtest)
+suppressPackageStartupMessages(library(lmtest))
 
 skip_if_not_installed("sandwich")
-library(sandwich)
+suppressPackageStartupMessages(library(sandwich))
 
 m <- lm(dist ~ speed, data = cars)
 ct <- lmtest::coeftest(m)
@@ -24,20 +22,20 @@ test_that("tidy.coeftest", {
   td <- tidy(ct)
   td2 <- tidy(ct2)
   td3 <- tidy(ct3)
-  
+
   check_tidy_output(td)
   check_tidy_output(td2)
   check_tidy_output(td3)
-  
+
   check_dims(td, 2, 5)
 
-  ## conf int
+  # conf int
   td_ci <- tidy(ct, conf.int = TRUE, conf.level = 0.9) %>%
     tibble::remove_rownames()
   check_tidy_output(td_ci)
   check_dims(td_ci, 2, 7)
 
-  ## should be like lm!
+  # should be like lm!
   td_lm_ci <- tidy(m, conf.int = TRUE, conf.level = 0.9) %>%
     tibble::remove_rownames()
   expect_equal(td_lm_ci, td_ci)
@@ -47,7 +45,19 @@ test_that("glance.coeftest", {
   gl <- glance(ct)
   gl2 <- glance(ct2)
   gl3 <- glance(ct3)
-  
-  check_glance_outputs(gl, gl3) 
+
+  check_glance_outputs(gl, gl3)
   check_glance_outputs(gl2) # separately because save = TRUE adds cols
 })
+
+test_that("vcovCL.coeftest (#1227)", {
+  m <- lm(Wind ~ 1, data = airquality)
+  ct <- coeftest(m, vcovCL(m, cluster = ~Month))
+  ct_confint <- confint(ct, level = .9)
+  output <- tidy(ct, conf.int = TRUE, conf.level = .9)
+  expect_equal(
+    output[c("conf.low", "conf.high")],
+    as.data.frame(ct_confint),
+    ignore_attr = TRUE
+  )
+})
