@@ -1,13 +1,10 @@
-context("margins")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
-skip("margins not available (#1200)")
-# skip_if_not_installed("margins")
-# library(margins)
+skip_if_not_installed("margins")
+suppressPackageStartupMessages(library(margins))
 
 fit1 <- glm(am ~ cyl + hp + wt, data = mtcars, family = binomial)
 marg1 <- margins(fit1)
