@@ -1,13 +1,14 @@
-context("stats-mlm")
-
 skip_on_cran()
 
+skip_if_not_installed("modeltests")
+library(modeltests)
+
 fit_mlm <- lm(cbind(mpg, disp) ~ wt, mtcars)
 df_tidy <- tidy(fit_mlm, conf.int = TRUE)
 
 test_that("tidy.mlm works", {
   expect_equal(dim(df_tidy), c(4L, 8L))
-  expect_is(df_tidy, "tbl_df")
+  expect_s3_class(df_tidy, "tbl_df")
 })
 
 #' helper function: replicate each element of x
@@ -25,7 +26,6 @@ rep_each <- function(x, times) {
 }
 
 test_that("tidy.mlm works", {
-
   # create data
   nob <- 100
   set.seed(1234)
