@@ -1,10 +1,8 @@
-context("survival-coxph")
-
 skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("survival")
-library(survival)
+suppressPackageStartupMessages(library(survival))
 
 fit <- coxph(Surv(time, status) ~ age + sex, lung)
 fit2 <- coxph(Surv(time, status) ~ age + sex, lung, robust = TRUE)
@@ -17,6 +15,13 @@ fit4 <- coxph(Surv(stop, event) ~ (rx + size + number) * strata(enum) +
 # this model does not have summary(x)$used.robust
 fit5 <- coxph(Surv(time, status) ~ age + pspline(nodes), data = colon)
 
+colon$super_long_variable_name_that_would_be_truncated <- colon$nodes
+
+# see #1153
+fit6 <- coxph(Surv(time, status) ~ age + 
+                pspline(super_long_variable_name_that_would_be_truncated), 
+              data = colon)
+
 test_that("coxph tidier arguments", {
   check_arguments(tidy.coxph)
   check_arguments(glance.coxph)
@@ -35,6 +40,7 @@ test_that("tidy.coxph", {
   td9 <- tidy(fit4, conf.int = TRUE)
   td10 <- tidy(fit5)
   td11 <- tidy(fit5, conf.int = TRUE)
+  td12 <- tidy(fit6, maxlabel = 1000)
 
   check_tidy_output(td)
   check_tidy_output(td2)
@@ -47,6 +53,12 @@ test_that("tidy.coxph", {
   check_tidy_output(td9)
   check_tidy_output(td10)
   check_tidy_output(td11)
+  check_tidy_output(td12)
+  
+  expect_equal(
+    td12$term[2],
+    "pspline(super_long_variable_name_that_would_be_truncated), linear"
+  )
 })
 
 test_that("glance.coxph", {
