@@ -1,12 +1,10 @@
-context("survival-survfit")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("survival")
-library(survival)
+suppressPackageStartupMessages(library(survival))
 
 cfit <- coxph(Surv(time, status) ~ age + strata(sex), lung)
 sfit <- survfit(cfit)
@@ -34,16 +32,9 @@ test_that("tidy.survfit", {
 })
 
 test_that("glance.survfit", {
-  expect_error(
-    glance(sfit),
-    regexp = "Cannot construct a glance of a multi-strata survfit object."
-  )
-
-  expect_error(
-    glance(fit2),
-    regexp = "Cannot construct a glance of a multi-state survfit object."
-  )
-
+  expect_snapshot(error = TRUE, glance(sfit))
+  expect_snapshot(error = TRUE, glance(fit2))
+  
   gl <- glance(sfit2)
   check_glance_outputs(gl)
 })
