@@ -1,12 +1,10 @@
-context("survival-survreg")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("survival")
-library(survival)
+suppressPackageStartupMessages(library(survival))
 
 sr <- survreg(Surv(futime, fustat) ~ ecog.ps + rx, ovarian,
   dist = "exponential"
@@ -38,11 +36,6 @@ test_that("glance.survreg", {
 })
 
 test_that("augment.survreg", {
-  expect_error(
-    augment(sr),
-    regexp = "Must specify either `data` or `newdata` argument."
-  )
-
   check_augment_function(
     aug = augment.survreg,
     model = sr,
