@@ -1,10 +1,8 @@
-context("tseries")
-
 skip_if_not_installed("modeltests")
-library(modeltests)
+suppressPackageStartupMessages(library(modeltests))
 
-skip_if_not_installed("tseries")
-library(tseries)
+suppressMessages(skip_if_not_installed("tseries"))
+suppressPackageStartupMessages(library(tseries))
 
 dax <- diff(log(EuStockMarkets))[, "DAX"]
 fit <- garch(dax, control = garch.control(trace = FALSE))
@@ -18,6 +16,10 @@ test_that("tidy.garch", {
   td <- tidy(fit)
   check_tidy_output(td)
   check_dims(td, 3)
+
+  td <- tidy(fit, conf.int = TRUE, conf.level = .99)
+  check_tidy_output(td)
+  check_dims(td, 3, 7)
 })
 
 test_that("glance.garch", {
